@@ -2,7 +2,7 @@
 
 """mesh_sync provides entry point main()."""
 
-__version__ = "1.0.2"
+__version__ = "1.0.3"
 
 import base64
 import re
@@ -168,20 +168,21 @@ def main():
             if git_url is not None:
                 print(">> Found git url: %s" % git_url)
                 get_update_file(auth_token=token, repo_url=git_url)
-            else:
-                print(">> Could not find .git url")
-                git_url_input = input("Please enter the git url: ")
-                if git_url_input is not None:
-                    is_empty = os.listdir(os.getcwd()) == []
-                    if is_empty:
-                        print(">> No files found in the current directory, downloading latest version...")
-                        get_all_files(token, f"https://api.github.com/repos/{git_url}/git/trees/master?recursive=1")
-                    else:
-                        print(">> Found files in the current directory, updating latest version...")
-                        get_update_file(auth_token=token, repo_url=git_url)
+        else:
+            print(">> Could not find .git url")
+            git_url_input = input("Please enter the git url: ")
+            git_url_input = git_url_input.rstrip('/')
+            if git_url_input is not None:
+                is_empty = os.listdir(os.getcwd()) == []
+                if is_empty:
+                    print(">> No files found in the current directory, downloading latest version...")
+                    get_all_files(token, f"https://api.github.com/repos/{git_url_input}/git/trees/master?recursive=1")
                 else:
-                    print("Please enter a valid git url. Aborting...")
-                    sys.exit(0)
+                    print(">> Found files in the current directory, updating latest version...")
+                    get_update_file(auth_token=token, repo_url=git_url_input)
+            else:
+                print("Please enter a valid git url. Aborting...")
+                sys.exit(0)
     except Exception as e:
         print("Error: %s" % e)
         sys.exit(0)
